/* Part of Misnamed Filter Configurator (see Program.cs)
 * by Alex Vallat <www.byalexv.co.uk>
 */
using System;
using System.Collections.Generic;
using System.Text;
using System.Xml;

namespace MisnamedFilter
{
	public class AddressSet
	{
		public AddressSet()
		{
		}
		public AddressSet(XmlElement addressSetElement)
		{
			mDescriptiveName = addressSetElement.GetAttribute("descriptiveName");
			foreach (XmlElement addressPatternElement in addressSetElement.SelectNodes("EmailAddressPatterns/EmailAddressPattern"))
			{
				mAddressPatterns.Add(addressPatternElement.InnerText);
			}
			foreach (XmlElement namePatternElement in addressSetElement.SelectNodes("NamePatterns/NamePattern"))
			{
				mNamePatterns.Add(namePatternElement.InnerText);
			}
		}
		private string mDescriptiveName = String.Empty;
		public string DescriptiveName
		{
			get { return mDescriptiveName; }
			set { mDescriptiveName = value; }
		}

		private List<string> mAddressPatterns = new List<string>();
		public List<string> AddressPatterns
		{
			get { return mAddressPatterns; }
		}
		private List<string> mNamePatterns = new List<string>();
		public List<string> NamePatterns
		{
			get { return mNamePatterns; }
		}

		public override string ToString()
		{
			return DescriptiveName;
		}

		public XmlElement Serialise(XmlDocument doc)
		{
			XmlElement addressSetElement = doc.CreateElement("AddressSet");
			addressSetElement.SetAttribute("descriptiveName", DescriptiveName);
			XmlElement addressPatterns = (XmlElement)addressSetElement.AppendChild(doc.CreateElement("EmailAddressPatterns"));
			foreach (string pattern in AddressPatterns)
			{
				addressPatterns.AppendChild(doc.CreateElement("EmailAddressPattern")).InnerText = pattern;
			}

			XmlElement namePatterns = (XmlElement)addressSetElement.AppendChild(doc.CreateElement("NamePatterns"));
			foreach (string pattern in NamePatterns)
			{
				namePatterns.AppendChild(doc.CreateElement("NamePattern")).InnerText = pattern;
			}

			return addressSetElement;
		}
	}
}
